@@ -16,6 +16,6 @@ class FnHttpStatusData(AJsonPlPgSqlFunction):
         return (
             f" {Arg.result} := {BFn.jsonb_build_object}("
             f"    '{CA.HttpStatus}', ({Arg.input}->>'{CA.HttpStatus}')::SMALLINT, "
-            f"    '{CA.Data}', ({Arg.input}->>'{CA.Data}')::JSONB"  
-            f"  )"
+            f"          '{CA.Data}', ({Arg.input}->>'{CA.Data}')::JSONB"  
+            f" );"
         )
\ No newline at end of file
