@@ -22,7 +22,7 @@ def create_table_descriptions(conn, sc: str, table: str):
 
     cursor.execute(
         f" CREATE UNIQUE INDEX {sc}_{table}_{CC.formatted_description} "
-        f" ON {sc_table}({CC.formatted_description});")
+        f" ON {sc_table}({CC.formatted_description}, {CC.plain_description});")
 
     insert_empty_description(sc_table, CC.description_id, cursor)
     set_max_id_for_serial_column(sc, table, CC.description_id, cursor)
